nbxmpp.transports_nb.NonBlockingHTTPBOSH

Package nbxmpp :: Module transports_nb :: Class NonBlockingHTTPBOSH |
[hide private]
[frames] | no frames]

# Class NonBlockingHTTPBOSH

source code

Class for BOSH HTTP connections. Slightly redefines HTTP transport by calling bosh bodytag generating callback before putting data on wire

Instance Methods | [hide private]
set_stanza_build_cb(self, build_cb) | source code
_do_send(self) Called when send() to connected socket is possible. First message from sendqueue will be sent | source code
Inherited from `NonBlockingHTTP`: `__init__`, `build_http_message`, `http_send`, `parse_http_message` Inherited from `NonBlockingHTTP` (private): `_on_receive` Inherited from `NonBlockingTCP`: `connect`, `disconnect`, `encode_stanza`, `pollend`, `pollin`, `pollout`, `read_timeout`, `remove_timeout`, `send`, `set_timeout`, `start_disconnect`, `tls_init` Inherited from `NonBlockingTCP` (private): `_connect_to_proxy`, `_do_receive`, `_on_connect`, `_plug_idle` Inherited from `NonBlockingTransport`: `get_fd`, `get_state`, `onreceive`, `plugin`, `plugout`, `read_timeout2`, `renew_send_timeout`, `renew_send_timeout2`, `set_send_timeout`, `set_send_timeout2`, `set_state`, `set_timeout2` Inherited from `NonBlockingTransport` (private): `_on_connect_failure`, `_tcp_connecting_started` Inherited from `plugin.PlugIn`: `PlugIn`, `PlugOut`

Class Methods | [hide private]
Inherited from `plugin.PlugIn`: `get_instance`

Instance Variables | [hide private]
Inherited from `idlequeue.IdleObject`: `fd`

Method Details | [hide private]

### set_stanza_build_cb(self, build_cb) | source code

### _do_send(self) | source code
Called when send() to connected socket is possible. First message from sendqueue will be sent Overrides: NonBlockingTCP._do_send (inherited documentation)